---
title: API Reference
description: API reference
---

# API Reference

In this section you can find detailed documentation of every object and function that `hikari-arc` exports. If you're new to `arc` it is recommended you take a look at the [guides](../guides/index.md) first.

If you think something is missing or inaccurate, please [open an issue](https://github.com/hypergonial/hikari-arc/issues/new/choose)!
